summaryrefslogtreecommitdiff
path: root/gdb/avr-tdep.c
diff options
context:
space:
mode:
authorTheodore A. Roth <troth@openavr.org>2003-05-14 20:09:14 +0000
committerTheodore A. Roth <troth@openavr.org>2003-05-14 20:09:14 +0000
commit5a66be41fc45b337204ba6fc6d82585a4eb04f2c (patch)
treeec2602eada4038753c437d577ead7f2b16943d46 /gdb/avr-tdep.c
parente7d9b5587148408c8d6ea297ad3f19756a7c74d7 (diff)
downloadgdb-5a66be41fc45b337204ba6fc6d82585a4eb04f2c.tar.gz
* MAINTAINERS: Update my email address.
* avr-tdep.c: Ditto.
Diffstat (limited to 'gdb/avr-tdep.c')
-rw-r--r--gdb/avr-tdep.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/gdb/avr-tdep.c b/gdb/avr-tdep.c
index 386b3861629..b84e90c4552 100644
--- a/gdb/avr-tdep.c
+++ b/gdb/avr-tdep.c
@@ -19,7 +19,7 @@
Foundation, Inc., 59 Temple Place - Suite 330,
Boston, MA 02111-1307, USA. */
/* Contributed by Theodore A. Roth, troth@verinet.com */
/* Portions of this file were taken from the original gdb-4.18 patch developed
by Denis Chertykov, denisc@overta.ru */
@@ -331,7 +331,7 @@ avr_pointer_to_address (struct type *type, const void *buf)
fprintf_unfiltered (gdb_stderr, "CODE_SPACE ---->> ptr->addr: 0x%lx\n",
addr);
fprintf_unfiltered (gdb_stderr,
- "+++ If you see this, please send me an email <troth@verinet.com>\n");
+ "+++ If you see this, please send me an email <troth@openavr.org>\n");
}
/* Is it a code address? */
@@ -19,7 +19,7 @@
Foundation, Inc., 59 Temple Place - Suite 330,
Boston, MA 02111-1307, USA. */
-/* Contributed by Theodore A. Roth, troth@verinet.com */
+/* Contributed by Theodore A. Roth, troth@openavr.org */
/* Portions of this file were taken from the original gdb-4.18 patch developed
by Denis Chertykov, denisc@overta.ru */